# Youtube Mashup Project
# Made by Pulkit - 102003619


## Project Description
This module is used to create mashup of youtube video audios. 
It takes four Inputs.
It takes string ```Name of the Singer```, int ```number of youtube videos``` , int ```duration of audio from each videos``` and .mp3```Name of audio file by which final mashup audio will be saved```.


## Requirements
```pip install pytube```
```pip install pydub```
```pip install pandas```

## Installation
```pip install Mashup-Pulkit-102003619```

## or Alternatively use 
```python -m pip install Mashup-Pulkit-102003619```

## Sample execution command format
python "python file to be executed" number_of_videos duration_of_audio "output_filename.mp3"


## License

© 2023 Pulkit

This repository is licensed under the MIT license. See LICENSE for details.